OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Невідома адреса",
    "No result." : "Жодного результату.",
    "Malformed JSON data." : "Неправильні дані JSON.",
    "Error" : "Помилка",
    "Weather status" : "Прогноз погоди",
    "Weather status in your dashboard" : "Статус погоди на вашій інформаційній панелі",
    "Weather status integrated in the Dashboard app.\n    The geographic location can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Стан погоди інтегрований в додаток Dashboard.\n    Географічне розташування може бути визначено автоматично або вручну. Потім відображається прогноз на 6 годин.\n    Цей статус також може бути інтегрований в інші місця, наприклад, в додаток \"Календар\".",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} ясне небо пізніше сьогодні",
    "{temperature} {unit} clear sky" : "{temperature} {unit} ясне небо",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} хмарно пізніше сьогодні",
    "{temperature} {unit} cloudy" : "{temperature} {unit} хмарно",
    "{temperature} {unit} snow and thunder later today" : "{temperature} {unit} сніг та грім сьогодні ввечері",
    "{temperature} {unit} snow and thunder" : "{temperature} {unit} сніг і грім",
    "{temperature} {unit} snow showers and thunder later today" : "{temperature} {unit} сьогодні ввечері снігопад та грім",
    "{temperature} {unit} snow showers and thunder" : "{temperature} {unit} снігові зливи та грім",
    "{temperature} {unit} snow showers, thunder and polar twilight later today" : "{temperature} {unit} сьогодні ввечері снігопади, грім та полярні сутінки",
    "{temperature} {unit} snow showers, thunder and polar twilight" : "{temperature} {unit} снігові зливи, грім і полярні сутінки",
    "{temperature} {unit} snow showers later today" : "{temperature} {unit} Сьогодні ввечері сніг зі снігом.",
    "{temperature} {unit} snow showers" : "{temperature} {unit} снігопади",
    "{temperature} {unit} snow showers and polar twilight later today" : "{temperature} {unit} Сьогодні ввечері снігопади та полярні сутінки",
    "{temperature} {unit} snow showers and polar twilight" : "{temperature} {unit} снігопади та полярні сутінки",
    "{temperature} {unit} snow later today" : "{temperature} {unit} Сьогодні сніг.",
    "{temperature} {unit} snow" : "{temperature} {unit} сніг",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} гарна погода пізніше сьогодні",
    "{temperature} {unit} fair weather" : "{temperature} {unit} гарна погода",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} мінлива хмарність пізніше сьогодні",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} мінлива хмарність",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} туман пізніше сьогодні",
    "{temperature} {unit} foggy" : "{temperature} {unit} туман",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} невеликий дощ пізніше сьогодні",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} невеликий дощ",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} опадів пізніше сьогодні",
    "{temperature} {unit} rainfall" : "{temperature} {unit} опади",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} сьогодні сильний дощ",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} сильні опади",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} дощ пізніше сьогодні",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} злива",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} невеликий дощ пізніше сьогодні",
    "{temperature} {unit} light rainfall showers" : " {temperature} {unit} невеликі дощові зливи",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} сильний дощ пізніше сьогодні",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} проливні дощі",
    "More weather for {adr}" : "Більше інформації про погоду для {adr}",
    "Loading weather" : "Завантаження інформації про стан погоди",
    "Set location for weather" : "Встановіть місце для погоди",
    "Remove from favorites" : "Прибрати зірочку",
    "Add as favorite" : "Позначити зірочкою",
    "You are not logged in." : "Ви не ввійшли до системи.",
    "There was an error getting the weather status information." : "Виникла помилка при отриманні інформації про стан погоди.",
    "No weather information found" : "Інформацію про погоду не знайдено",
    "Location not found" : "Місце розташування не знайдено",
    "There was an error setting the location address." : "Виникла помилка при встановленні адреси розташування.",
    "There was an error setting the location." : "Під час встановлення місця розташування сталася помилка.",
    "There was an error saving the mode." : "Під час збереження режиму сталася помилка.",
    "There was an error using personal address." : "Під час використання особистої адреси сталася помилка.",
    "Unknown weather code" : "Невідомий код погоди",
    "Detect location" : "Визначити місце розташування",
    "Set custom address" : "Встановити власну адресу",
    "Favorites" : "Із зірочкою"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
